==> maDB_1.4.0.tar.gz: maDB/man/getDBAnnotation.Rd <==
\name{dbGetAnnotation}
\alias{dbGetAnnotation}
\title{Annotate a list of IDs using the annotation table in the database.}
\description{
  \code{dbGetAnnotation} this function can be used to annotate a list of ids (for example Affymetrix IDs) using a formerly created annotation database.
}
\usage{
dbGetAnnotation(Con,id,columns=c("gen_bank","description","uni_gene","locuslink","symbol","chromosome"),chip=NULL,search.col="id",v=TRUE,quickload=FALSE)
}
\arguments{
  \item{Con}{A connection object (create it with the dbConnect.PgSQL.conn function from the package RdbiPgSQL)}
  \item{id}{The IDs of the genes that should be annotated.}
  \item{columns}{the identifier to which the submitted ids should be annotated.}
  \item{chip}{the chip (or for two color arrays a oligo set identifier) from which the ids were taken from (e.g. hgu133plus2 for the Affymetrix GeneChip 133Plus2).}
  \item{search.col}{In wich of the columns the ids submitted with the id parameter should be searched for.}
  \item{v}{If TRUE additional information will be printed to the console.}
  \item{quickload}{Only valid if id="id", the annotation data will be fetched much quicker from the database.}
}
\details{
The annotation table can be easily created in a PostgreSQL database using the \code{dbUpdateAnnotation} function.}
\references{}
\author{Johannes Rainer}

\seealso{
    \code{\link{dbUpdateAnnotation}}
    \code{\link{dbGetExperimentInfo}}
    \code{\link{dbConnect}}
    \code{\link{loadFromDB}}
}

\keyword{data}

==> maDB_1.6.0.tar.gz: maDB/man/getDBAnnotation.Rd <==
\name{dbGetAnnotation}
\alias{dbGetAnnotation}
\title{Annotate a list of IDs using the annotation table in the database.}
\description{
  \code{dbGetAnnotation} this function can be used to annotate a list of ids (for example Affymetrix IDs) using a formerly created annotation database.
}
\usage{
dbGetAnnotation(Con,id,columns=c("gen_bank","description","uni_gene","locuslink","symbol","chromosome"),chip=NULL,search.col="id",v=TRUE,quickload=FALSE)
}
\arguments{
  \item{Con}{A connection object (create it with the dbConnect.PgSQL.conn function from the package RdbiPgSQL)}
  \item{id}{The IDs of the genes that should be annotated.}
  \item{columns}{the identifier to which the submitted ids should be annotated.}
  \item{chip}{the chip (or for two color arrays a oligo set identifier) from which the ids were taken from (e.g. hgu133plus2 for the Affymetrix GeneChip 133Plus2).}
  \item{search.col}{In wich of the columns the ids submitted with the id parameter should be searched for.}
  \item{v}{If TRUE additional information will be printed to the console.}
  \item{quickload}{Only valid if id="id", the annotation data will be fetched much quicker from the database.}
}
\details{
The annotation table can be easily created in a PostgreSQL database using the \code{dbUpdateAnnotation} function.}
\references{}
\author{Johannes Rainer}

\seealso{
    \code{\link{dbUpdateAnnotation}}
    \code{\link{dbGetExperimentInfo}}
%    \code{\link{dbConnect}}
    \code{\link{loadFromDB}}
}

\keyword{data}
